# encoding: utf-8

# -------------------------------------------------------------------------------
# (C) Copyright 2019 - 2021 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty
# statements accompanying such products and services. Nothing herein should be
# construed as constituting an additional warranty. Micro Focus shall not be
# liable for technical or editorial errors or omissions contained herein. The
# information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential
# information and a valid license is required for possession, use or copying. If
# this work is provided to the U.S. Government, consistent with FAR 12.211 and
# 12.212, Commercial Computer Software, Computer Software Documentation, and
# Technical Data for Commercial Items  are licensed to the U.S. Government under
# vendor's standard commercial license.
# ------------------------------------------------------------------------------
# Copyright (c) 2006 Novell, Inc. All Rights Reserved.
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of version 2 of the GNU General Public License as published by the
# Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, contact Novell, Inc.
#
# To contact Novell about this file by physical or electronic mail, you may find
# current contact information at www.novell.com.
# ------------------------------------------------------------------------------

# File:	clients/novell-nssad.ycp
# Package:	Configuration of novell-nssad
# Summary:	Main file
# Authors:	Suresh K. Hosamani <hsuresh@novell.com>
#
# $Id: novell-nssad.ycp 27914 2006-02-13 14:32:08Z locilka $
#
# Main file for novell-nssad configuration. Uses all other files.
module Yast
  class NovellNssadClient < Client
    def main
      Yast.import "UI"

      #**
      # <h3>Configuration of novell-nssad</h3>

      textdomain "novell-nssad"

      # The main ()
      Builtins.y2milestone("----------------------------------------")
      Builtins.y2milestone("Novell Storage Services AD Support module started")

      Yast.import "Progress"
      Yast.import "Report"
      Yast.import "Summary"
      Yast.import "NovellAddonInstall"

      Yast.import "CommandLine"
      Yast.include self, "novell-nssad/wizards.rb"

      @cmdline_description = {
        "id"         => "novell-nssad",
        # Command line help text for the Xnovell-nssad module
        "help"       => _(
          "Configuration of OES Storage Services AD Support"
        ),
        "guihandler" => fun_ref(method(:NovellNssadSequence), "any ()"),
        "initialize" => fun_ref(NovellNssad.method(:Read), "boolean ()"),
        "finish"     => fun_ref(NovellNssad.method(:Write), "boolean ()"),
        "actions" =>
          # FIXME TODO: fill the functionality description here
          {},
        "options" =>
          # FIXME TODO: fill the option descriptions here
          {},
        "mappings" =>
          # FIXME TODO: fill the mappings of actions and options here
          {}
      }

      # is this proposal or not?
      @propose = false
      @args = WFM.Args
      if Ops.greater_than(Builtins.size(@args), 0)
        if Ops.is_path?(WFM.Args(0)) && WFM.Args(0) == path(".propose")
          Builtins.y2milestone("Using PROPOSE mode")
          @propose = true
        end
      end

      # main ui function
      @ret = nil

      if @propose
        if Ops.get(
            NovellAddonInstall.products_to_configure,
            "novell-nssad",
            true
          )
          @ret = NovellNssadAutoSequence()
        else
          @ret = :next
        end
      else
        @ret = CommandLine.Run(@cmdline_description)
      end
      Builtins.y2debug("ret=%1", @ret)


      # Finish
      Builtins.y2milestone("Novell Storage Services AD Support module finished")
      Builtins.y2milestone("----------------------------------------")

      deep_copy(@ret) 

      # EOF
    end
  end
end

Yast::NovellNssadClient.new.main
