# encoding: utf-8

# -------------------------------------------------------------------------------
# (C) Copyright 2019 - 2022 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty
# statements accompanying such products and services. Nothing herein should be
# construed as constituting an additional warranty. Micro Focus shall not be
# liable for technical or editorial errors or omissions contained herein. The
# information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential
# information and a valid license is required for possession, use or copying. If
# this work is provided to the U.S. Government, consistent with FAR 12.211 and
# 12.212, Commercial Computer Software, Computer Software Documentation, and
# Technical Data for Commercial Items  are licensed to the U.S. Government under
# vendor's standard commercial license.
# ------------------------------------------------------------------------------
# Copyright (c) 2006 Novell, Inc. All Rights Reserved.
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of version 2 of the GNU General Public License as published by the
# Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, contact Novell, Inc.
#
# To contact Novell about this file by physical or electronic mail, you may find
# current contact information at www.novell.com.
# ------------------------------------------------------------------------------

# File:	clients/novell-nssad_proposal.ycp
# Package:	Configuration of novell-nssad
# Summary:	Proposal function dispatcher.
# Authors:	Suresh K. Hosamani <hsuresh@novell.com>
#
# $Id: novell-nssad_proposal.ycp 41350 2007-10-10 16:59:00Z dfiser $
#
# Proposal function dispatcher for novell-nssad configuration.
# See source/installation/proposal/proposal-API.txt
module Yast
  class NovellNssadProposalClient < Client
    def main

      textdomain "novell-nssad"

      Yast.import "NovellNssad"
      Yast.import "Progress"
      Yast.import "NovellAddonInstall"
      Yast.import "NovellPatterns"

      # The main ()
      Builtins.y2milestone("----------------------------------------")
      Builtins.y2milestone(
        "Novell Storage Services AD Support proposal started"
      )

      @func = Convert.to_string(WFM.Args(0))
      @param = Convert.to_map(WFM.Args(1))
      @ret = {}

      # create a textual proposal
      if @func == "MakeProposal"
        @proposal = ""
        @warning = nil
        @warning_level = nil
        @force_reset = Ops.get_boolean(@param, "force_reset", false)

        if @force_reset || !NovellNssad.ProposalValid
          NovellNssad.SetProposalValid(true)
          @progress_orig = Progress.set(false)
          NovellNssad.Read
          Progress.set(@progress_orig)
          if ( Mode.update || Mode.autoupgrade ) && Ops.get_string(NovellNssad.oldSettings, "SERVICE_CONFIGURED", "") == "yes"
            Ops.set(NovellAddonInstall.products_to_configure, "novell-nssad", true)
          else
            Ops.set(NovellAddonInstall.products_to_configure, "novell-nssad", false)
          end
        end
        @sum = NovellNssad.Summary
        @proposal = Ops.get_string(@sum, 0, "")
        @ret = NovellAddonInstall.ConstructProposal("novell-nssad", @proposal)
      # validate the current values
      elsif @func == "ValidateValues"
        @ret = { "errors" => false }

        if !Mode.update && !Mode.autoupgrade
          #if the user needs to be warned, warn them and block on page
          if Ops.get_string(
              NovellNssad.Settings,
              "CONFIG_NSSAD_DOMAIN_NAME",
              ""
            ) == "" ||
              Ops.get_string(
                NovellNssad.Settings,
                "CONFIG_NSSAD_ADMIN_NAME",
                ""
              ) == "" ||
              Ops.get_string(
                NovellNssad.Settings,
                "CONFIG_NSSAD_ADMIN_PASSWORD",
                ""
              ) == ""
            Ops.set(@ret, "errors", true) if !NovellNssad.isDomainJoined
          end
        end
      # run the module
      elsif @func == "AskUser"
        Builtins.sleep(750)
        @chosen_id = Ops.get(@param, "chosen_id")
        Builtins.y2milestone("NovellNssad proposal changing id %1", @chosen_id)

        # Configure now
        if @chosen_id == "novell-nssad--configure_now"
          Ops.set(
            NovellAddonInstall.products_to_configure,
            "novell-nssad",
            true
          )
          @ret = { "workflow_sequence" => :next }
        elsif @chosen_id == "novell-nssad--configure_later"
          Ops.set(
            NovellAddonInstall.products_to_configure,
            "novell-nssad",
            false
          )
          @ret = { "workflow_sequence" => :next }
        else
          @stored = NovellNssad.Export
          @seq = Convert.to_symbol(
            WFM.CallFunction("novell-nssad", [path(".propose")])
          )
          NovellNssad.Import(@stored) if @seq != :next
          Builtins.y2debug("stored=%1", @stored)
          Builtins.y2debug("seq=%1", @seq)
          @ret = { "workflow_sequence" => @seq }
        end
      # create titles
      elsif @func == "Description"
        @isSelected = NovellPatterns.IsPatternInstalled("novell-nssad")
        Builtins.y2milestone(
          "Proposal:IsSelectionInstalled:novell-nssad: %1",
          @isSelected
        )
        if @isSelected == true
          @ret = {
            # Rich text title for NovellNssad in proposals
            "rich_text_title" => _(
              "OES Storage Services AD Support"
            ),
            # Menu title for NovellNssad in proposals
            "menu_title"      => _(
              "OES Storage Services &AD Support"
            ),
            "id"              => "novell-nssad"
          }
        else
          @ret = {}
        end
      # write the proposal
      elsif @func == "Write"
        NovellNssad.Write
      else
        Builtins.y2error("unknown function: %1", @func)
      end

      # Finish
      Builtins.y2debug("ret=%1", @ret)
      Builtins.y2milestone("Novell Active Directory proposal finished")
      Builtins.y2milestone("----------------------------------------")
      deep_copy(@ret)

      # EOF
    end
  end
end

Yast::NovellNssadProposalClient.new.main
