# encoding: utf-8

# -------------------------------------------------------------------------------
# (C) Copyright 2019 - 2022 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty
# statements accompanying such products and services. Nothing herein should be
# construed as constituting an additional warranty. Micro Focus shall not be
# liable for technical or editorial errors or omissions contained herein. The
# information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential
# information and a valid license is required for possession, use or copying. If
# this work is provided to the U.S. Government, consistent with FAR 12.211 and
# 12.212, Commercial Computer Software, Computer Software Documentation, and
# Technical Data for Commercial Items  are licensed to the U.S. Government under
# vendor's standard commercial license.
# ------------------------------------------------------------------------------
# Copyright (c) 2006 Novell, Inc. All Rights Reserved.
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of version 2 of the GNU General Public License as published by the
# Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, contact Novell, Inc.
#
# To contact Novell about this file by physical or electronic mail, you may find
# current contact information at www.novell.com.
# ------------------------------------------------------------------------------

# File:	include/novell-nssad/dialogs.ycp
# Package:	Configuration of novell-nssad
# Summary:	Dialogs definitions
# Authors:	Suresh K. Hosamani <hsuresh@novell.com>
#
# $Id: dialogs.ycp 27914 2006-02-13 14:32:08Z locilka $
module Yast
  module NovellNssadDialogsInclude
    def initialize_novell_nssad_dialogs(include_target)
      Yast.import "UI"

      textdomain "novell-nssad"

      Yast.import "Label"
      Yast.import "Wizard"
      Yast.import "NovellNssad"
      Yast.import "Address"
      Yast.import "Mode"
      Yast.import "Package"
      Yast.import "SambaAD"
      Yast.import "Directory"
      Yast.import "Report"
      Yast.import "EdirUtils"
      Yast.import "NovellUtils"
      Yast.import "NovellValidators"
      Yast.import "Edirectory"
      Yast.import "Nss"
      Yast.import "NovellPatterns"

      Yast.include include_target, "novell-nssad/helps.rb"
      Yast.include include_target, "novell-nssad/complex.rb"
    end

    # Configure1 dialog
    # @return dialog result
    def AcceptNssAdLicenseDialog
      pattern = "novell-nssad"
      if NovellPatterns.IsPatternInstalled(pattern) == false
        Builtins.y2milestone(
          "The required pattern, %1, is not installed.",
          pattern
        )
        if Mode.normal
          Report.Error(
            Builtins.sformat(
              _(
                "Configuration aborted. Install the required %1 pattern and try again."
              ),
              pattern
            )
          )
        end
        return :abort
      end

      if Mode.update || Mode.autoupgrade
     # skip gui on last two oes upgrade versions
        Popup.Message(NovellUtils.noConfigMessage)
        Builtins.y2milestone(
          "NovellNssad.AcceptNssAdLicenseDialog:skipping GUI since we are in upgrade mode."
        )
        return :move
      end

      license_group = false
      license_group = Ops.get_boolean(
        NovellNssad.Settings,
        "license_group",
        false
      )
      caption = _("User Access Restrictions")
      return :skip if NovellNssad.isDomainJoined

      contents = HVSquash(
        VBox(
          Frame(
            _(
              "To control access to the NSS resources for the Active Directory users:"
            ),
            MarginBox(
              1.5,
              0.2,
              VBox(
                Left(
                  Label(
                    _(
                      "\n" +
                        "Single Forest Environment: Create a Universal Group with the sAMAccountName\n" +
                        "\"OESAccessGrp\" anywhere in the AD forest. Only the members of this group will have\n" +
                        "access to the NSS resources based on their trustee assignments. In absence of this\n" +
                        "group, all the AD users in the forest can access the NSS resources based on their\n" +
                        "trustee assignments."
                    )
                  )
                ),
                Left(
                  Label(
                    _(
                      "Multi Forest Environment: Create a Domain Local Group (DLG) with the\n" +
                        "sAMAccountName \"DLOESAccessGrp\" in the AD domain to which this OES server is\n" +
                        "joined. Only the members of this group (OES forest and across forest) will have\n" +
                        "access to the NSS resources based on their trustee assignments. In absence of\n" +
                        "this group, the AD users across the forest cannot access the NSS resources."
                    )
                  )
                )
              )
            )
          ),
          Left(
            Label(
              _(
                "Before proceeding, ensure to refer the NSS AD Deployment guide."
              )
            )
          ),
          VSpacing(1.0),
          Left(
            CheckBox(
              Id(:license_group),
              Opt(:notify),
              _("&I have read these recommendations."),
              license_group
            )
          )
        )
      )
      Wizard.SetContentsButtons(
        caption,
        contents,
        Ops.get_string(@HELPS, "uac", ""),
        Label.BackButton,
        Label.NextButton
      )

      ret = nil

      if !Ops.get_boolean(NovellNssad.Settings, "license_group", false)
        Wizard.DisableNextButton
      end

      while true
        ret = UI.UserInput
        if ret == :license_group
          if Convert.to_boolean(UI.QueryWidget(Id(:license_group), :Value))
            Ops.set(NovellNssad.Settings, "license_group", true)
            Wizard.EnableNextButton
          else
            Wizard.DisableNextButton
          end
        elsif ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        end
        if ret == :back
          break
        elsif ret == :next
          return :next
        end
      end

      nil
    end

    # Configure1 dialog
    # @return dialog result
    def ConfigureNssAdDialog
      # NovellNssad configure1 dialog caption
      caption = _("OES Storage Services AD Support Configuration")
      domain_name = Ops.get_string(
        NovellNssad.Settings,
        "CONFIG_NSSAD_DOMAIN_NAME",
        ""
      )
      adminName = Ops.get_string(
        NovellNssad.Settings,
        "CONFIG_NSSAD_ADMIN_NAME",
        ""
      )
      ad_context = Ops.get_string(
        NovellNssad.Settings,
        "CONFIG_NSSAD_CONTEXT",
        ""
      )
      domain_admin_group = Ops.get_string(
        NovellNssad.Settings,
        "CONFIG_NSSAD_ADMIN_GROUP",
        ""
      )
      pre_created_object = false

      if Ops.get_string(
          NovellNssad.Settings,
          "CONFIG_NSSAD_PRECREATED_OBJECT",
          ""
        ) == "yes"
        pre_created_object = true
      end

      #	boolean enable_ssh_scp = false;
      #    if (NovellNssad::Settings["CONFIG_NSSAD_ENABLE_SSHSCP"]:"" == "yes")

      #        enable_ssh_scp = true;

      ad_uid_generate_mode = false
      if Ops.get_string(NovellNssad.Settings, "AD_UID_GENERATE_MODE", "") == "yes"
        ad_uid_generate_mode = true
      else
        ad_uid_generate_mode = false
      end
      contents = HVSquash(
        VBox(
          MinWidth(
            50,
            HBox(
              TextEntry(
                Id(:domain_name),
                Opt(:notify),
                _("&AD Domain Name"),
                domain_name
              )
            )
          ),
          TextEntry(
            Id(:domain_admin_group),
            Opt(:notify),
            _("AD Super&visor Group"),
            domain_admin_group
          ),
          TextEntry(Id(:adminName), _("A&D User Name"), adminName),
          Left(Password(Id(:adminPassword), Opt(:hstretch), _("&Password"), "")),
          TextEntry(
            Id(:ad_context),
            _("&Container to create Computer Object"),
            ad_context
          ),
          Left(
            CheckBox(
              Id(:pre_created_object),
              Opt(:notify),
              _("&Use pre-created computer object"),
              pre_created_object
            )
          ),
          #             `Left(`CheckBox(`id(`enable_ssh_scp), `opt(`notify), _("Enable SSH/SCP for AD users"), enable_ssh_scp)),
          VBox(
            VSpacing(1),
            Left(Label(_("Novell Identity Translator (NIT) Configuration"))),
            Left(
              CheckBox(
                Id(:ad_uid_generate_mode),
                Opt(:notify),
                _("Genera&te UIDs for AD users"),
                ad_uid_generate_mode
              )
            )
          )
        )
      )
      contents = HVSquash(VBox(contents, Nss.NitRangeDialog))
      helps = Ops.get_string(@HELPS, "c1", "")
      Wizard.SetContentsButtons(
        caption,
        contents,
        helps,
        Label.BackButton,
        Label.NextButton
      )

      if NovellNssad.isDomainJoined
        UI.ChangeWidget(Id(:domain_name), :Enabled, false)
        UI.ChangeWidget(Id(:domain_admin_group), :Enabled, false)
        UI.ChangeWidget(Id(:adminName), :Enabled, false)
        UI.ChangeWidget(Id(:adminPassword), :Enabled, false)
        UI.ChangeWidget(Id(:ad_context), :Enabled, false)
        UI.ChangeWidget(Id(:pre_created_object), :Enabled, false)
      end
      #        if (tointeger(NovellUtils::CleanUpString(val["stdout"]:"")) != 0)



      #	UI::ChangeWidget(`id(`domain_name),`Enabled,false);
      if ad_uid_generate_mode
        #		UI::ChangeWidget(`id(`ad_uid_generate_mode),`Enabled,true);
        UI.ChangeWidget(Id(:start_range), :Enabled, true)
        UI.ChangeWidget(Id(:end_range), :Enabled, true)
      else
        #		UI::ChangeWidget(`id(`ad_uid_generate_mode),`Enabled,false);
        UI.ChangeWidget(Id(:start_range), :Enabled, false)
        UI.ChangeWidget(Id(:end_range), :Enabled, false)
      end

      ret = nil
      while true
        ret = UI.UserInput

        # abort?
        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        # Commenting this code as ssh/scp option is removed from the builds
        # else if (ret == `enable_ssh_scp)
        #     {
        #         boolean enable_ssh_scp = (boolean)UI::QueryWidget(`id(`enable_ssh_scp), `Value);
        #         boolean ad_uid_generate_mode =  (boolean)UI::QueryWidget(`id(`ad_uid_generate_mode), `Value);
        #         if(ad_uid_generate_mode)
        #         {
        #             boolean goon = Popup::YesNo(sformat(_("You cannot select \"Enable SSH/SCP for AD users\" when you have\nchosen to generate UIDs using NIT. Do you want to deselect it? ")));
        #             if(goon)
        #             {
        #                 UI::ChangeWidget(`id(`enable_ssh_scp),`Value,false);
        #             }
        #             else
        #             {
        #                 Nss::NitReadSettings();
        #                 UI::ChangeWidget(`id(`ad_uid_generate_mode),`Value,false);
        #                 UI::ChangeWidget(`id(`start_range),`Value, Nss::Settings_nit["CONFIG_NIT_START_RANGE"]:100000);
        #                 UI::ChangeWidget(`id(`end_range),`Value, Nss::Settings_nit["CONFIG_NIT_END_RANGE"]:200000);
        #                 UI::ChangeWidget(`id(`start_range),`Enabled,false);
        #                 UI::ChangeWidget(`id(`end_range),`Enabled,false);
        #             }
        #         }
        #     }
        #     else if(ret == `ad_uid_generate_mode)
        #     {
        #         boolean enable_ssh_scp = (boolean)UI::QueryWidget(`id(`enable_ssh_scp), `Value);
        #         boolean ad_uid_generate_mode =  (boolean)UI::QueryWidget(`id(`ad_uid_generate_mode), `Value);
        #
        #         if(enable_ssh_scp)
        #         {
        #             boolean goon = Popup::YesNo(sformat(_("You cannot select \"Generate UID for AD users\" when \"Enable SSH/SCP for AD\nusers\" is selected. Do you want to deselect \"Enable SSH/SCP for AD users\" ?")));
        #             if(goon)
        #             {
        #                 UI::ChangeWidget(`id(`enable_ssh_scp),`Value,false);
        #                 UI::ChangeWidget(`id(`start_range),`Enabled,true);
        #                 UI::ChangeWidget(`id(`end_range),`Enabled,true);
        #             }
        #             else
        #             {
        #                 Nss::NitReadSettings();
        #                 UI::ChangeWidget(`id(`ad_uid_generate_mode),`Value,false);
        #                 UI::ChangeWidget(`id(`start_range),`Value, Nss::Settings_nit["CONFIG_NIT_START_RANGE"]:100000);
        #                 UI::ChangeWidget(`id(`end_range),`Value, Nss::Settings_nit["CONFIG_NIT_END_RANGE"]:200000);
        #                 UI::ChangeWidget(`id(`start_range),`Enabled,false);
        #                 UI::ChangeWidget(`id(`end_range),`Enabled,false);
        #             }
        #         }
        #         else
        #         {
        #             boolean ad_uid_generate_mode =  (boolean)UI::QueryWidget(`id(`ad_uid_generate_mode), `Value);
        #             if (ad_uid_generate_mode)
        #             {
        #                 UI::ChangeWidget(`id(`start_range),`Enabled,true);
        #                 UI::ChangeWidget(`id(`end_range),`Enabled,true);
        #             }
        #             else
        #             {
        #                 Nss::NitReadSettings();
        #                 UI::ChangeWidget(`id(`start_range),`Value, Nss::Settings_nit["CONFIG_NIT_START_RANGE"]:100000);
        #                 UI::ChangeWidget(`id(`end_range),`Value, Nss::Settings_nit["CONFIG_NIT_END_RANGE"]:200000);
        #                 UI::ChangeWidget(`id(`start_range),`Enabled,false);
        #                 UI::ChangeWidget(`id(`end_range),`Enabled,false);
        #   			}
        #         }
        #     }
        elsif ret == :ad_uid_generate_mode
          ad_uid_generate_mode2 = Convert.to_boolean(
            UI.QueryWidget(Id(:ad_uid_generate_mode), :Value)
          )
          if ad_uid_generate_mode2
            UI.ChangeWidget(Id(:start_range), :Enabled, true)
            UI.ChangeWidget(Id(:end_range), :Enabled, true)
          else
            UI.ChangeWidget(Id(:start_range), :Enabled, false)
            UI.ChangeWidget(Id(:end_range), :Enabled, false)
            Nss.NitReadSettings
            UI.ChangeWidget(
              Id(:start_range),
              :Value,
              Ops.get_integer(
                Nss.Settings_nit,
                "CONFIG_NIT_START_RANGE",
                100000
              )
            )
            UI.ChangeWidget(
              Id(:end_range),
              :Value,
              Ops.get_integer(Nss.Settings_nit, "CONFIG_NIT_END_RANGE", 200000)
            )
          end
        elsif ret == :pre_created_object
          pre_created_object2 = Convert.to_boolean(
            UI.QueryWidget(Id(:pre_created_object), :Value)
          )
          if pre_created_object2
            Ops.set(
              NovellNssad.Settings,
              "CONFIG_NSSAD_PRECREATED_OBJECT",
              "yes"
            )
          else
            Ops.set(
              NovellNssad.Settings,
              "CONFIG_NSSAD_PRECREATED_OBJECT",
              "no"
            )
          end
        elsif ret == :next
          domain_name = Convert.to_string(
            UI.QueryWidget(Id(:domain_name), :Value)
          )
          domain_name = Builtins.toupper(domain_name)
          if domain_name == nil || domain_name == ""
            Popup.Error(_("Domain or Workgroup name cannot be empty."))
            next
            UI.SetFocus(Id(:domain_name))
          end

          domain_admin_group = Convert.to_string(
            UI.QueryWidget(Id(:domain_admin_group), :Value)
          )
          # adminname validation
          adminName = Convert.to_string(UI.QueryWidget(Id(:adminName), :Value))
          if adminName == "" || adminName == nil
            Report.Error(Builtins.sformat(_("Admin context cannot be empty.")))
            next
          end
          if !NovellNssad.isDomainJoined
            adminPassword = Convert.to_string(
              UI.QueryWidget(Id(:adminPassword), :Value)
            )
            if adminPassword == nil || adminPassword == ""
              Popup.Error(_("Admin password cannot be empty."))
              next
              UI.SetFocus(Id(:adminPassword))
            end
            ad_context = Convert.to_string(
              UI.QueryWidget(Id(:ad_context), :Value)
            )
            if ad_context == "" || ad_context == nil
              ad_context = "cn=Computers"
              UI.ChangeWidget(Id(:ad_context), :Value, ad_context)
            else
              cmd = Builtins.sformat(
                "/opt/novell/xad/bin/kinit -E %1@%2",
                adminName,
                domain_name
              )
              cmd = Builtins.sformat("ADM_PASSWD='%1' %2", adminPassword, cmd)
              val = Convert.to_map(
                SCR.Execute(path(".target.bash_output"), cmd)
              )
              exit = Ops.get_integer(val, "exit", -1)
              Builtins.y2milestone("map output %1", val)
              if exit != 0
                Report.Error(
                  _(
                    "kinit has failed. Retry with the correct AD configuration details.\nFor more information, see /var/log/YaST2/y2log"
                  )
                )
                Builtins.y2milestone(
                  "kinit has failed. Retry with the correct AD configuration details."
                )
                next
              end

              cmd = Builtins.sformat(
                "/opt/novell/bin/novell-ad-util --validate-container --context '%1' --domain-name '%2'",
                ad_context,
                domain_name
              )
              val = Convert.to_map(
                SCR.Execute(path(".target.bash_output"), cmd)
              )
              Builtins.y2milestone("map output %1", val)
              exit = Ops.get_integer(val, "exit", -1)
              if exit != 0
                if exit == 4
                  Report.Error(
                    Builtins.sformat(
                      _(
                        "The specified container (%1) does not exist in the AD server."
                      ),
                      ad_context
                    )
                  )
                  Builtins.y2milestone(
                    "The specified container (%1) does not exist in the AD server.",
                    ad_context
                  )
                  next
                  UI.SetFocus(Id(:ad_context))
                end
                if exit == 21
                  Report.Error(
                    Builtins.sformat(
                      _(
                        "The reverse zone entry verification failed for the domain controller.\nEnsure that the reverse zone entry exists in the DNS."
                      )
                    )
                  )
                  Builtins.y2milestone(
                    "The reverse zone entry verification failed for the domain controller. Ensure that the reverse zone entry exists in the DNS."
                  )
                  next
                  UI.SetFocus(Id(:ad_context))
                else
                  Report.Error(
                    Builtins.sformat(
                      _(
                        "Verification of container object failed. Ensure that the AD Server is reachable."
                      )
                    )
                  )
                  Builtins.y2milestone(
                    "Verification of container object failed. Ensure that the AD Server is reachable."
                  )
                  next
                end
              end
            end
          end

          #  		boolean enable_ssh_scp = (boolean)UI::QueryWidget(`id(`enable_ssh_scp),`Value);
          #        if(enable_ssh_scp)
          #    	    NovellNssad::Settings["CONFIG_NSSAD_ENABLE_SSHSCP"] = "yes";
          #        else
          #        	NovellNssad::Settings["CONFIG_NSSAD_ENABLE_SSHSCP"] = "no";

          Ops.set(NovellNssad.Settings, "CONFIG_NSSAD_DOMAIN_NAME", domain_name)
          Ops.set(
            NovellNssad.Settings,
            "CONFIG_NSSAD_ADMIN_GROUP",
            domain_admin_group
          )
          Ops.set(NovellNssad.Settings, "CONFIG_NSSAD_ADMIN_NAME", adminName)
          Ops.set(
            NovellNssad.Settings,
            "CONFIG_NSSAD_ADMIN_PASSWORD",
            adminPassword
          )
          Ops.set(NovellNssad.Settings, "CONFIG_NSSAD_CONTEXT", ad_context)

          ad_uid_generate_mode2 = Convert.to_boolean(
            UI.QueryWidget(Id(:ad_uid_generate_mode), :Value)
          )
          if ad_uid_generate_mode2
            Ops.set(NovellNssad.Settings, "AD_UID_GENERATE_MODE", "yes")
          else
            Ops.set(NovellNssad.Settings, "AD_UID_GENERATE_MODE", "no")
          end

          next if Nss.NitRangeNextButton == :continue

          break
        elsif ret == :domain_name
          next
        elsif ret == :back
          if NovellNssad.isDomainJoined #978407
            return :abort
          end
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end
      deep_copy(ret)
    end
  end
end
