# encoding: utf-8

# -------------------------------------------------------------------------------
# (C) Copyright 2019 - 2021 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty
# statements accompanying such products and services. Nothing herein should be
# construed as constituting an additional warranty. Micro Focus shall not be
# liable for technical or editorial errors or omissions contained herein. The
# information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential
# information and a valid license is required for possession, use or copying. If
# this work is provided to the U.S. Government, consistent with FAR 12.211 and
# 12.212, Commercial Computer Software, Computer Software Documentation, and
# Technical Data for Commercial Items  are licensed to the U.S. Government under
# vendor's standard commercial license.
# ------------------------------------------------------------------------------
# Copyright (c) 2006 Novell, Inc. All Rights Reserved.
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of version 2 of the GNU General Public License as published by the
# Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, contact Novell, Inc.
#
# To contact Novell about this file by physical or electronic mail, you may find
# current contact information at www.novell.com.
# ------------------------------------------------------------------------------

# File:	include/novell-nssad/wizards.ycp
# Package:	Configuration of novell-nssad
# Summary:	Wizards definitions
# Authors:	Suresh K. Hosamani <hsuresh@novell.com>
#
# $Id: wizards.ycp 27914 2006-02-13 14:32:08Z locilka $
module Yast
  module NovellNssadWizardsInclude
    def initialize_novell_nssad_wizards(include_target)
      Yast.import "UI"

      textdomain "novell-nssad"

      Yast.import "Sequencer"
      Yast.import "Wizard"

      Yast.include include_target, "novell-nssad/complex.rb"
      Yast.include include_target, "novell-nssad/dialogs.rb"
    end

    # Main workflow of the novell-nssad configuration
    # @return sequence result
    def MainSequence
      # FIXME: adapt to your needs
      aliases = { "license" => lambda { AcceptNssAdLicenseDialog() }, "nssad" => lambda(
      ) do
        ConfigureNssAdDialog()
      end }


      # FIXME: adapt to your needs
      sequence = {
        "ws_start" => "license",
        "license"  => {
          :abort => :abort,
          :next  => "nssad",
          :skip  => "nssad",
          :move  => :next
        },
        "nssad"    => { :abort => :abort, :next => :next }
      }

      ret = Sequencer.Run(aliases, sequence)

      deep_copy(ret)
    end

    # Whole configuration of novell-nssad
    # @return sequence result
    def NovellNssadSequence
      aliases = {
        "read"  => [lambda { ReadDialog() }, true],
        "main"  => lambda { MainSequence() },
        "write" => [lambda { WriteDialog() }, true]
      }

      sequence = {
        "ws_start" => "read",
        "read"     => { :abort => :abort, :next => "main" },
        "main"     => { :abort => :abort, :next => "write" },
        "write"    => { :abort => :abort, :next => :next }
      }

      Wizard.CreateDialog

      ret = Sequencer.Run(aliases, sequence)

      UI.CloseDialog
      deep_copy(ret)
    end

    # Whole configuration of novell-nssad but without reading and writing.
    # For use with autoinstallation.
    # @return sequence result
    def NovellNssadAutoSequence
      # Initialization dialog caption
      caption = _("OES Storage Services AD Support Configuration")
      # Initialization dialog contents
      contents = Label(_("Initializing..."))

      Wizard.CreateDialog
      Wizard.SetContentsButtons(
        caption,
        contents,
        "",
        Label.BackButton,
        Label.NextButton
      )

      ret = MainSequence()

      UI.CloseDialog
      deep_copy(ret)
    end
  end
end
